"""Add Game7 mainnet indexes

Revision ID: c1bc596631f9
Revises: 6807bdf6f417
Create Date: 2024-10-14 16:10:27.757094

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'c1bc596631f9'
down_revision: Union[str, None] = '6807bdf6f417'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('game7_blocks',
    sa.Column('l1_block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('parent_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('transactions_indexed_at', sa.DateTime(timezone=True), nullable=True),
    sa.Column('logs_indexed_at', sa.DateTime(timezone=True), nullable=True),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('block_number', name=op.f('pk_game7_blocks'))
    )
    op.create_index(op.f('ix_game7_blocks_block_number'), 'game7_blocks', ['block_number'], unique=False)
    op.create_index(op.f('ix_game7_blocks_block_timestamp'), 'game7_blocks', ['block_timestamp'], unique=False)
    op.create_table('game7_reorgs',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_game7_reorgs'))
    )
    op.create_index(op.f('ix_game7_reorgs_block_hash'), 'game7_reorgs', ['block_hash'], unique=False)
    op.create_index(op.f('ix_game7_reorgs_block_number'), 'game7_reorgs', ['block_number'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_game7_reorgs_block_number'), table_name='game7_reorgs')
    op.drop_index(op.f('ix_game7_reorgs_block_hash'), table_name='game7_reorgs')
    op.drop_table('game7_reorgs')
    op.drop_index(op.f('ix_game7_blocks_block_timestamp'), table_name='game7_blocks')
    op.drop_index(op.f('ix_game7_blocks_block_number'), table_name='game7_blocks')
    op.drop_table('game7_blocks')
    # ### end Alembic commands ###



"""Add contracts tables

Revision ID: 82ff1541f4b4
Revises: c1bc596631f9
Create Date: 2024-11-04 14:29:45.303216

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "82ff1541f4b4"
down_revision: Union[str, None] = "c1bc596631f9"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "bytecode_storage",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode", sa.Text(), nullable=False),
        sa.Column("title", sa.VARCHAR(length=256), nullable=True),
        sa.Column("description", sa.Text(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("code", sa.Text(), nullable=True),
        sa.Column("data", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_bytecode_storage")),
        sa.UniqueConstraint("hash", name="uq_bytecode_storage_hash"),
    )
    op.create_index(
        op.f("ix_bytecode_storage_hash"), "bytecode_storage", ["hash"], unique=False
    )
    op.create_table(
        "arbitrum_one_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_arbitrum_one_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_arbitrum_one_contracts")),
    )
    op.create_index(
        op.f("ix_arbitrum_one_contracts_deployed_bytecode_hash"),
        "arbitrum_one_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_arbitrum_one_contracts_name"),
        "arbitrum_one_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_arbitrum_one_contracts_transaction_hash"),
        "arbitrum_one_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "arbitrum_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f(
                "fk_arbitrum_sepolia_contracts_bytecode_storage_id_bytecode_storage"
            ),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_arbitrum_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_arbitrum_sepolia_contracts_deployed_bytecode_hash"),
        "arbitrum_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_arbitrum_sepolia_contracts_name"),
        "arbitrum_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_arbitrum_sepolia_contracts_transaction_hash"),
        "arbitrum_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "b3_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_b3_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_b3_contracts")),
    )
    op.create_index(
        op.f("ix_b3_contracts_deployed_bytecode_hash"),
        "b3_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_b3_contracts_name"), "b3_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_b3_contracts_transaction_hash"),
        "b3_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "b3_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_b3_sepolia_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_b3_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_b3_sepolia_contracts_deployed_bytecode_hash"),
        "b3_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_b3_sepolia_contracts_name"),
        "b3_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_b3_sepolia_contracts_transaction_hash"),
        "b3_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "ethereum_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_ethereum_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_ethereum_contracts")),
    )
    op.create_index(
        op.f("ix_ethereum_contracts_deployed_bytecode_hash"),
        "ethereum_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ethereum_contracts_name"), "ethereum_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_ethereum_contracts_transaction_hash"),
        "ethereum_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "game7_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_game7_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_game7_contracts")),
    )
    op.create_index(
        op.f("ix_game7_contracts_deployed_bytecode_hash"),
        "game7_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_contracts_name"), "game7_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_game7_contracts_transaction_hash"),
        "game7_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "game7_orbit_arbitrum_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f(
                "fk_game7_orbit_arbitrum_sepolia_contracts_bytecode_storage_id_bytecode_storage"
            ),
        ),
        sa.PrimaryKeyConstraint(
            "address", name=op.f("pk_game7_orbit_arbitrum_sepolia_contracts")
        ),
    )
    op.create_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_deployed_bytecode_hash"),
        "game7_orbit_arbitrum_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_name"),
        "game7_orbit_arbitrum_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_transaction_hash"),
        "game7_orbit_arbitrum_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "game7_testnet_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f(
                "fk_game7_testnet_contracts_bytecode_storage_id_bytecode_storage"
            ),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_game7_testnet_contracts")),
    )
    op.create_index(
        op.f("ix_game7_testnet_contracts_deployed_bytecode_hash"),
        "game7_testnet_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_contracts_name"),
        "game7_testnet_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_contracts_transaction_hash"),
        "game7_testnet_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "imx_zkevm_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_imx_zkevm_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_imx_zkevm_contracts")),
    )
    op.create_index(
        op.f("ix_imx_zkevm_contracts_deployed_bytecode_hash"),
        "imx_zkevm_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_imx_zkevm_contracts_name"),
        "imx_zkevm_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_imx_zkevm_contracts_transaction_hash"),
        "imx_zkevm_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "imx_zkevm_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f(
                "fk_imx_zkevm_sepolia_contracts_bytecode_storage_id_bytecode_storage"
            ),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_imx_zkevm_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_imx_zkevm_sepolia_contracts_deployed_bytecode_hash"),
        "imx_zkevm_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_imx_zkevm_sepolia_contracts_name"),
        "imx_zkevm_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_imx_zkevm_sepolia_contracts_transaction_hash"),
        "imx_zkevm_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "mantle_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_mantle_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_mantle_contracts")),
    )
    op.create_index(
        op.f("ix_mantle_contracts_deployed_bytecode_hash"),
        "mantle_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_mantle_contracts_name"), "mantle_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_mantle_contracts_transaction_hash"),
        "mantle_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "mantle_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f(
                "fk_mantle_sepolia_contracts_bytecode_storage_id_bytecode_storage"
            ),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_mantle_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_mantle_sepolia_contracts_deployed_bytecode_hash"),
        "mantle_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_mantle_sepolia_contracts_name"),
        "mantle_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_mantle_sepolia_contracts_transaction_hash"),
        "mantle_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "polygon_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_polygon_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_polygon_contracts")),
    )
    op.create_index(
        op.f("ix_polygon_contracts_deployed_bytecode_hash"),
        "polygon_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_polygon_contracts_name"), "polygon_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_polygon_contracts_transaction_hash"),
        "polygon_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_sepolia_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_sepolia_contracts_deployed_bytecode_hash"),
        "sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_sepolia_contracts_name"), "sepolia_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_sepolia_contracts_transaction_hash"),
        "sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "xai_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_xai_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_xai_contracts")),
    )
    op.create_index(
        op.f("ix_xai_contracts_deployed_bytecode_hash"),
        "xai_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_xai_contracts_name"), "xai_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_xai_contracts_transaction_hash"),
        "xai_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "xai_sepolia_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_xai_sepolia_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_xai_sepolia_contracts")),
    )
    op.create_index(
        op.f("ix_xai_sepolia_contracts_deployed_bytecode_hash"),
        "xai_sepolia_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_xai_sepolia_contracts_name"),
        "xai_sepolia_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_xai_sepolia_contracts_transaction_hash"),
        "xai_sepolia_contracts",
        ["transaction_hash"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        op.f("ix_xai_sepolia_contracts_transaction_hash"),
        table_name="xai_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_xai_sepolia_contracts_name"), table_name="xai_sepolia_contracts"
    )
    op.drop_index(
        op.f("ix_xai_sepolia_contracts_deployed_bytecode_hash"),
        table_name="xai_sepolia_contracts",
    )
    op.drop_table("xai_sepolia_contracts")
    op.drop_index(op.f("ix_xai_contracts_transaction_hash"), table_name="xai_contracts")
    op.drop_index(op.f("ix_xai_contracts_name"), table_name="xai_contracts")
    op.drop_index(
        op.f("ix_xai_contracts_deployed_bytecode_hash"), table_name="xai_contracts"
    )
    op.drop_table("xai_contracts")
    op.drop_index(
        op.f("ix_sepolia_contracts_transaction_hash"), table_name="sepolia_contracts"
    )
    op.drop_index(op.f("ix_sepolia_contracts_name"), table_name="sepolia_contracts")
    op.drop_index(
        op.f("ix_sepolia_contracts_deployed_bytecode_hash"),
        table_name="sepolia_contracts",
    )
    op.drop_table("sepolia_contracts")
    op.drop_index(
        op.f("ix_polygon_contracts_transaction_hash"), table_name="polygon_contracts"
    )
    op.drop_index(op.f("ix_polygon_contracts_name"), table_name="polygon_contracts")
    op.drop_index(
        op.f("ix_polygon_contracts_deployed_bytecode_hash"),
        table_name="polygon_contracts",
    )
    op.drop_table("polygon_contracts")
    op.drop_index(
        op.f("ix_mantle_sepolia_contracts_transaction_hash"),
        table_name="mantle_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_mantle_sepolia_contracts_name"), table_name="mantle_sepolia_contracts"
    )
    op.drop_index(
        op.f("ix_mantle_sepolia_contracts_deployed_bytecode_hash"),
        table_name="mantle_sepolia_contracts",
    )
    op.drop_table("mantle_sepolia_contracts")
    op.drop_index(
        op.f("ix_mantle_contracts_transaction_hash"), table_name="mantle_contracts"
    )
    op.drop_index(op.f("ix_mantle_contracts_name"), table_name="mantle_contracts")
    op.drop_index(
        op.f("ix_mantle_contracts_deployed_bytecode_hash"),
        table_name="mantle_contracts",
    )
    op.drop_table("mantle_contracts")
    op.drop_index(
        op.f("ix_imx_zkevm_sepolia_contracts_transaction_hash"),
        table_name="imx_zkevm_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_imx_zkevm_sepolia_contracts_name"),
        table_name="imx_zkevm_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_imx_zkevm_sepolia_contracts_deployed_bytecode_hash"),
        table_name="imx_zkevm_sepolia_contracts",
    )
    op.drop_table("imx_zkevm_sepolia_contracts")
    op.drop_index(
        op.f("ix_imx_zkevm_contracts_transaction_hash"),
        table_name="imx_zkevm_contracts",
    )
    op.drop_index(op.f("ix_imx_zkevm_contracts_name"), table_name="imx_zkevm_contracts")
    op.drop_index(
        op.f("ix_imx_zkevm_contracts_deployed_bytecode_hash"),
        table_name="imx_zkevm_contracts",
    )
    op.drop_table("imx_zkevm_contracts")
    op.drop_index(
        op.f("ix_game7_testnet_contracts_transaction_hash"),
        table_name="game7_testnet_contracts",
    )
    op.drop_index(
        op.f("ix_game7_testnet_contracts_name"), table_name="game7_testnet_contracts"
    )
    op.drop_index(
        op.f("ix_game7_testnet_contracts_deployed_bytecode_hash"),
        table_name="game7_testnet_contracts",
    )
    op.drop_table("game7_testnet_contracts")
    op.drop_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_transaction_hash"),
        table_name="game7_orbit_arbitrum_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_name"),
        table_name="game7_orbit_arbitrum_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_deployed_bytecode_hash"),
        table_name="game7_orbit_arbitrum_sepolia_contracts",
    )
    op.drop_table("game7_orbit_arbitrum_sepolia_contracts")
    op.drop_index(
        op.f("ix_game7_contracts_transaction_hash"), table_name="game7_contracts"
    )
    op.drop_index(op.f("ix_game7_contracts_name"), table_name="game7_contracts")
    op.drop_index(
        op.f("ix_game7_contracts_deployed_bytecode_hash"), table_name="game7_contracts"
    )
    op.drop_table("game7_contracts")
    op.drop_index(
        op.f("ix_ethereum_contracts_transaction_hash"), table_name="ethereum_contracts"
    )
    op.drop_index(op.f("ix_ethereum_contracts_name"), table_name="ethereum_contracts")
    op.drop_index(
        op.f("ix_ethereum_contracts_deployed_bytecode_hash"),
        table_name="ethereum_contracts",
    )
    op.drop_table("ethereum_contracts")
    op.drop_index(
        op.f("ix_b3_sepolia_contracts_transaction_hash"),
        table_name="b3_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_b3_sepolia_contracts_name"), table_name="b3_sepolia_contracts"
    )
    op.drop_index(
        op.f("ix_b3_sepolia_contracts_deployed_bytecode_hash"),
        table_name="b3_sepolia_contracts",
    )
    op.drop_table("b3_sepolia_contracts")
    op.drop_index(op.f("ix_b3_contracts_transaction_hash"), table_name="b3_contracts")
    op.drop_index(op.f("ix_b3_contracts_name"), table_name="b3_contracts")
    op.drop_index(
        op.f("ix_b3_contracts_deployed_bytecode_hash"), table_name="b3_contracts"
    )
    op.drop_table("b3_contracts")
    op.drop_index(
        op.f("ix_arbitrum_sepolia_contracts_transaction_hash"),
        table_name="arbitrum_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_arbitrum_sepolia_contracts_name"),
        table_name="arbitrum_sepolia_contracts",
    )
    op.drop_index(
        op.f("ix_arbitrum_sepolia_contracts_deployed_bytecode_hash"),
        table_name="arbitrum_sepolia_contracts",
    )
    op.drop_table("arbitrum_sepolia_contracts")
    op.drop_index(
        op.f("ix_arbitrum_one_contracts_transaction_hash"),
        table_name="arbitrum_one_contracts",
    )
    op.drop_index(
        op.f("ix_arbitrum_one_contracts_name"), table_name="arbitrum_one_contracts"
    )
    op.drop_index(
        op.f("ix_arbitrum_one_contracts_deployed_bytecode_hash"),
        table_name="arbitrum_one_contracts",
    )
    op.drop_table("arbitrum_one_contracts")
    op.drop_index(op.f("ix_bytecode_storage_hash"), table_name="bytecode_storage")
    op.drop_table("bytecode_storage")
    # ### end Alembic commands ###



"""Add deployed by column

Revision ID: 5ce23893771f
Revises: 82ff1541f4b4
Create Date: 2024-11-07 14:03:31.833443

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "5ce23893771f"
down_revision: Union[str, None] = "82ff1541f4b4"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "arbitrum_one_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_arbitrum_one_contracts_deployed_by"),
        "arbitrum_one_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "arbitrum_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_arbitrum_sepolia_contracts_deployed_by"),
        "arbitrum_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "b3_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_b3_contracts_deployed_by"),
        "b3_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "b3_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_b3_sepolia_contracts_deployed_by"),
        "b3_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "ethereum_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_ethereum_contracts_deployed_by"),
        "ethereum_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "game7_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_game7_contracts_deployed_by"),
        "game7_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "game7_orbit_arbitrum_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_deployed_by"),
        "game7_orbit_arbitrum_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "game7_testnet_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_game7_testnet_contracts_deployed_by"),
        "game7_testnet_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "imx_zkevm_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_imx_zkevm_contracts_deployed_by"),
        "imx_zkevm_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "imx_zkevm_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_imx_zkevm_sepolia_contracts_deployed_by"),
        "imx_zkevm_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "mantle_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_mantle_contracts_deployed_by"),
        "mantle_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "mantle_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_mantle_sepolia_contracts_deployed_by"),
        "mantle_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "polygon_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_polygon_contracts_deployed_by"),
        "polygon_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_sepolia_contracts_deployed_by"),
        "sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "xai_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_xai_contracts_deployed_by"),
        "xai_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.add_column(
        "xai_sepolia_contracts",
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
    )
    op.create_index(
        op.f("ix_xai_sepolia_contracts_deployed_by"),
        "xai_sepolia_contracts",
        ["deployed_by"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        op.f("ix_xai_sepolia_contracts_deployed_by"), table_name="xai_sepolia_contracts"
    )
    op.drop_column("xai_sepolia_contracts", "deployed_by")
    op.drop_index(op.f("ix_xai_contracts_deployed_by"), table_name="xai_contracts")
    op.drop_column("xai_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_sepolia_contracts_deployed_by"), table_name="sepolia_contracts"
    )
    op.drop_column("sepolia_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_polygon_contracts_deployed_by"), table_name="polygon_contracts"
    )
    op.drop_column("polygon_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_mantle_sepolia_contracts_deployed_by"),
        table_name="mantle_sepolia_contracts",
    )
    op.drop_column("mantle_sepolia_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_mantle_contracts_deployed_by"), table_name="mantle_contracts"
    )
    op.drop_column("mantle_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_imx_zkevm_sepolia_contracts_deployed_by"),
        table_name="imx_zkevm_sepolia_contracts",
    )
    op.drop_column("imx_zkevm_sepolia_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_imx_zkevm_contracts_deployed_by"), table_name="imx_zkevm_contracts"
    )
    op.drop_column("imx_zkevm_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_game7_testnet_contracts_deployed_by"),
        table_name="game7_testnet_contracts",
    )
    op.drop_column("game7_testnet_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_game7_orbit_arbitrum_sepolia_contracts_deployed_by"),
        table_name="game7_orbit_arbitrum_sepolia_contracts",
    )
    op.drop_column("game7_orbit_arbitrum_sepolia_contracts", "deployed_by")
    op.drop_index(op.f("ix_game7_contracts_deployed_by"), table_name="game7_contracts")
    op.drop_column("game7_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_ethereum_contracts_deployed_by"), table_name="ethereum_contracts"
    )
    op.drop_column("ethereum_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_b3_sepolia_contracts_deployed_by"), table_name="b3_sepolia_contracts"
    )
    op.drop_column("b3_sepolia_contracts", "deployed_by")
    op.drop_index(op.f("ix_b3_contracts_deployed_by"), table_name="b3_contracts")
    op.drop_column("b3_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_arbitrum_sepolia_contracts_deployed_by"),
        table_name="arbitrum_sepolia_contracts",
    )
    op.drop_column("arbitrum_sepolia_contracts", "deployed_by")
    op.drop_index(
        op.f("ix_arbitrum_one_contracts_deployed_by"),
        table_name="arbitrum_one_contracts",
    )
    op.drop_column("arbitrum_one_contracts", "deployed_by")
    # ### end Alembic commands ###



"""Immutable zkEvm with it's sepolia blockchains

Revision ID: 211646463e9f
Revises: 090c247f8618
Create Date: 2024-07-25 14:14:41.548326

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = '211646463e9f'
down_revision: Union[str, None] = '090c247f8618'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('imx_zkevm_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.LargeBinary(), nullable=True),
    sa.Column('origin_address', sa.LargeBinary(), nullable=True),
    sa.Column('address', sa.LargeBinary(), nullable=False),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_imx_zkevm_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_imx_zkevm_labels_id'))
    )
    op.create_index('ix_imx_zkevm_labels_addr_block_num', 'imx_zkevm_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_imx_zkevm_labels_addr_block_ts', 'imx_zkevm_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_address'), 'imx_zkevm_labels', ['address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_block_number'), 'imx_zkevm_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_caller_address'), 'imx_zkevm_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_label'), 'imx_zkevm_labels', ['label'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_label_name'), 'imx_zkevm_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_label_type'), 'imx_zkevm_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_origin_address'), 'imx_zkevm_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_labels_transaction_hash'), 'imx_zkevm_labels', ['transaction_hash'], unique=False)
    op.create_index('uk_imx_zkevm_labels_tx_hash_log_idx_evt', 'imx_zkevm_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_imx_zkevm_labels_tx_hash_log_idx_evt_raw', 'imx_zkevm_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.create_index('uk_imx_zkevm_labels_tx_hash_tx_call', 'imx_zkevm_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.create_index('uk_imx_zkevm_labels_tx_hash_tx_call_raw', 'imx_zkevm_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    op.create_table('imx_zkevm_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.LargeBinary(), nullable=True),
    sa.Column('origin_address', sa.LargeBinary(), nullable=True),
    sa.Column('address', sa.LargeBinary(), nullable=False),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_imx_zkevm_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_imx_zkevm_sepolia_labels_id'))
    )
    op.create_index('ix_imx_zkevm_sepolia_labels_addr_block_num', 'imx_zkevm_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_imx_zkevm_sepolia_labels_addr_block_ts', 'imx_zkevm_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_address'), 'imx_zkevm_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_block_number'), 'imx_zkevm_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_caller_address'), 'imx_zkevm_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_label'), 'imx_zkevm_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_label_name'), 'imx_zkevm_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_label_type'), 'imx_zkevm_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_origin_address'), 'imx_zkevm_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_labels_transaction_hash'), 'imx_zkevm_sepolia_labels', ['transaction_hash'], unique=False)
    op.create_index('uk_imx_zkevm_sepolia_labels_tx_hash_log_idx_evt', 'imx_zkevm_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_imx_zkevm_sepolia_labels_tx_hash_log_idx_evt_raw', 'imx_zkevm_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.create_index('uk_imx_zkevm_sepolia_labels_tx_hash_tx_call', 'imx_zkevm_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.create_index('uk_imx_zkevm_sepolia_labels_tx_hash_tx_call_raw', 'imx_zkevm_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('uk_imx_zkevm_sepolia_labels_tx_hash_tx_call_raw', table_name='imx_zkevm_sepolia_labels', postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    op.drop_index('uk_imx_zkevm_sepolia_labels_tx_hash_tx_call', table_name='imx_zkevm_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_imx_zkevm_sepolia_labels_tx_hash_log_idx_evt_raw', table_name='imx_zkevm_sepolia_labels', postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.drop_index('uk_imx_zkevm_sepolia_labels_tx_hash_log_idx_evt', table_name='imx_zkevm_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_transaction_hash'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_origin_address'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_label_type'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_label_name'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_label'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_caller_address'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_block_number'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_labels_address'), table_name='imx_zkevm_sepolia_labels')
    op.drop_index('ix_imx_zkevm_sepolia_labels_addr_block_ts', table_name='imx_zkevm_sepolia_labels')
    op.drop_index('ix_imx_zkevm_sepolia_labels_addr_block_num', table_name='imx_zkevm_sepolia_labels')
    op.drop_table('imx_zkevm_sepolia_labels')
    op.drop_index('uk_imx_zkevm_labels_tx_hash_tx_call_raw', table_name='imx_zkevm_labels', postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    op.drop_index('uk_imx_zkevm_labels_tx_hash_tx_call', table_name='imx_zkevm_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_imx_zkevm_labels_tx_hash_log_idx_evt_raw', table_name='imx_zkevm_labels', postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.drop_index('uk_imx_zkevm_labels_tx_hash_log_idx_evt', table_name='imx_zkevm_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index(op.f('ix_imx_zkevm_labels_transaction_hash'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_origin_address'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_label_type'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_label_name'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_label'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_caller_address'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_block_number'), table_name='imx_zkevm_labels')
    op.drop_index(op.f('ix_imx_zkevm_labels_address'), table_name='imx_zkevm_labels')
    op.drop_index('ix_imx_zkevm_labels_addr_block_ts', table_name='imx_zkevm_labels')
    op.drop_index('ix_imx_zkevm_labels_addr_block_num', table_name='imx_zkevm_labels')
    op.drop_table('imx_zkevm_labels')
    # ### end Alembic commands ###



"""add ronin chain

Revision ID: 8610f3c98043
Revises: 5ce23893771f
Create Date: 2024-11-12 12:54:26.532910

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "8610f3c98043"
down_revision: Union[str, None] = "5ce23893771f"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "ronin_blocks",
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("parent_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("row_id", sa.BigInteger(), nullable=False),
        sa.Column("path", sa.Text(), nullable=False),
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column(
            "indexed_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("block_number", name=op.f("pk_ronin_blocks")),
    )
    op.create_index(
        op.f("ix_ronin_blocks_block_number"),
        "ronin_blocks",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_blocks_block_timestamp"),
        "ronin_blocks",
        ["block_timestamp"],
        unique=False,
    )
    op.create_table(
        "ronin_reorgs",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_ronin_reorgs")),
    )
    op.create_index(
        op.f("ix_ronin_reorgs_block_hash"), "ronin_reorgs", ["block_hash"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_reorgs_block_number"),
        "ronin_reorgs",
        ["block_number"],
        unique=False,
    )
    op.create_table(
        "ronin_saigon_blocks",
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("parent_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("row_id", sa.BigInteger(), nullable=False),
        sa.Column("path", sa.Text(), nullable=False),
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column(
            "indexed_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("block_number", name=op.f("pk_ronin_saigon_blocks")),
    )
    op.create_index(
        op.f("ix_ronin_saigon_blocks_block_number"),
        "ronin_saigon_blocks",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_blocks_block_timestamp"),
        "ronin_saigon_blocks",
        ["block_timestamp"],
        unique=False,
    )
    op.create_table(
        "ronin_saigon_reorgs",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_ronin_saigon_reorgs")),
    )
    op.create_index(
        op.f("ix_ronin_saigon_reorgs_block_hash"),
        "ronin_saigon_reorgs",
        ["block_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_reorgs_block_number"),
        "ronin_saigon_reorgs",
        ["block_number"],
        unique=False,
    )
    op.create_table(
        "ronin_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_ronin_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_ronin_contracts")),
    )
    op.create_index(
        op.f("ix_ronin_contracts_deployed_by"),
        "ronin_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_contracts_deployed_bytecode_hash"),
        "ronin_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_contracts_name"), "ronin_contracts", ["name"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_contracts_transaction_hash"),
        "ronin_contracts",
        ["transaction_hash"],
        unique=False,
    )
    op.create_table(
        "ronin_saigon_contracts",
        sa.Column("address", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_by", sa.LargeBinary(length=20), nullable=False),
        sa.Column("deployed_bytecode", sa.Text(), nullable=False),
        sa.Column("deployed_bytecode_hash", sa.VARCHAR(length=32), nullable=False),
        sa.Column("bytecode_storage_id", sa.UUID(), nullable=True),
        sa.Column("abi", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column("deployed_at_block_number", sa.BigInteger(), nullable=False),
        sa.Column("deployed_at_block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("deployed_at_block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_index", sa.BigInteger(), nullable=False),
        sa.Column("name", sa.VARCHAR(length=256), nullable=True),
        sa.Column("statistics", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "supported_standards",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["bytecode_storage_id"],
            ["bytecode_storage.id"],
            name=op.f("fk_ronin_saigon_contracts_bytecode_storage_id_bytecode_storage"),
        ),
        sa.PrimaryKeyConstraint("address", name=op.f("pk_ronin_saigon_contracts")),
    )
    op.create_index(
        op.f("ix_ronin_saigon_contracts_deployed_by"),
        "ronin_saigon_contracts",
        ["deployed_by"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_contracts_deployed_bytecode_hash"),
        "ronin_saigon_contracts",
        ["deployed_bytecode_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_contracts_name"),
        "ronin_saigon_contracts",
        ["name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_contracts_transaction_hash"),
        "ronin_saigon_contracts",
        ["transaction_hash"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        op.f("ix_ronin_saigon_contracts_transaction_hash"),
        table_name="ronin_saigon_contracts",
    )
    op.drop_index(
        op.f("ix_ronin_saigon_contracts_name"), table_name="ronin_saigon_contracts"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_contracts_deployed_bytecode_hash"),
        table_name="ronin_saigon_contracts",
    )
    op.drop_index(
        op.f("ix_ronin_saigon_contracts_deployed_by"),
        table_name="ronin_saigon_contracts",
    )
    op.drop_table("ronin_saigon_contracts")
    op.drop_index(
        op.f("ix_ronin_contracts_transaction_hash"), table_name="ronin_contracts"
    )
    op.drop_index(op.f("ix_ronin_contracts_name"), table_name="ronin_contracts")
    op.drop_index(
        op.f("ix_ronin_contracts_deployed_bytecode_hash"), table_name="ronin_contracts"
    )
    op.drop_index(op.f("ix_ronin_contracts_deployed_by"), table_name="ronin_contracts")
    op.drop_table("ronin_contracts")
    op.drop_index(
        op.f("ix_ronin_saigon_reorgs_block_number"), table_name="ronin_saigon_reorgs"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_reorgs_block_hash"), table_name="ronin_saigon_reorgs"
    )
    op.drop_table("ronin_saigon_reorgs")
    op.drop_index(
        op.f("ix_ronin_saigon_blocks_block_timestamp"), table_name="ronin_saigon_blocks"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_blocks_block_number"), table_name="ronin_saigon_blocks"
    )
    op.drop_table("ronin_saigon_blocks")
    op.drop_index(op.f("ix_ronin_reorgs_block_number"), table_name="ronin_reorgs")
    op.drop_index(op.f("ix_ronin_reorgs_block_hash"), table_name="ronin_reorgs")
    op.drop_table("ronin_reorgs")
    op.drop_index(op.f("ix_ronin_blocks_block_timestamp"), table_name="ronin_blocks")
    op.drop_index(op.f("ix_ronin_blocks_block_number"), table_name="ronin_blocks")
    op.drop_table("ronin_blocks")
    # ### end Alembic commands ###



"""declarative indexes

Revision ID: c79044e047fe
Revises: dae735afc98f
Create Date: 2025-02-10 13:43:05.099092

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = 'c79044e047fe'
down_revision: Union[str, None] = 'dae735afc98f'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
  
    op.create_index('ix_amoy_labels_label_addr_name', 'amoy_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_arbitrum_nova_labels_label_addr_name', 'arbitrum_nova_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_arbitrum_one_labels_label_addr_name', 'arbitrum_one_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_arbitrum_sepolia_labels_addr_block_ts', 'arbitrum_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_arbitrum_sepolia_labels_label_addr_name', 'arbitrum_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_avalanche_fuji_labels_addr_block_ts', 'avalanche_fuji_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_avalanche_fuji_labels_label_addr_name', 'avalanche_fuji_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_avalanche_labels_addr_block_ts', 'avalanche_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_avalanche_labels_label_addr_name', 'avalanche_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_b3_labels_label_addr_name', 'b3_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_b3_sepolia_labels_label_addr_name', 'b3_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_base_labels_addr_block_ts', 'base_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_base_labels_label_addr_name', 'base_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_blast_labels_label_addr_name', 'blast_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_blast_sepolia_labels_label_addr_name', 'blast_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_ethereum_labels_addr_block_ts', 'ethereum_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_ethereum_labels_label_addr_name', 'ethereum_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_game7_labels_label_addr_name', 'game7_labels', ['label', 'address', 'label_name'], unique=False)
    op.drop_index('ix_g7o_arbitrum_sepolia_labels_addr_block_num', table_name='game7_orbit_arbitrum_sepolia_labels')
    op.drop_index('ix_g7o_arbitrum_sepolia_labels_addr_block_ts', table_name='game7_orbit_arbitrum_sepolia_labels')
    op.drop_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where="(((label)::text = 'seer'::text) AND ((label_type)::text = 'event'::text))")
    op.drop_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where="(((label)::text = 'seer-raw'::text) AND ((label_type)::text = 'event'::text))")
    op.drop_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where="(((label)::text = 'seer'::text) AND ((label_type)::text = 'tx_call'::text))")
    op.drop_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call_raw', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where="(((label)::text = 'seer-raw'::text) AND ((label_type)::text = 'tx_call'::text))")
    op.create_index('ix_game7_orbit_arbitrum_sepolia_labels_addr_block_num', 'game7_orbit_arbitrum_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_game7_orbit_arbitrum_sepolia_labels_addr_block_ts', 'game7_orbit_arbitrum_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_game7_orbit_arbitrum_sepolia_labels_label_addr_name', 'game7_orbit_arbitrum_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_log_idx_evt', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.create_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_tx_call', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.create_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_tx_call_raw', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    op.create_index('ix_game7_testnet_labels_label_addr_name', 'game7_testnet_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_imx_zkevm_labels_label_addr_name', 'imx_zkevm_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_imx_zkevm_sepolia_labels_label_addr_name', 'imx_zkevm_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_mantle_labels_label_addr_name', 'mantle_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_mantle_sepolia_labels_label_addr_name', 'mantle_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_mumbai_labels_addr_block_ts', 'mumbai_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_mumbai_labels_label_addr_name', 'mumbai_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_polygon_labels_addr_block_ts', 'polygon_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_polygon_labels_label_addr_name', 'polygon_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_proofofplay_apex_labels_label_addr_name', 'proofofplay_apex_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_ronin_labels_label_addr_name', 'ronin_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_ronin_saigon_labels_label_addr_name', 'ronin_saigon_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_sepolia_labels_addr_block_ts', 'sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_sepolia_labels_label_addr_name', 'sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_starknet_labels_addr_block_ts', 'starknet_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_starknet_labels_label_addr_name', 'starknet_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_starknet_sepolia_labels_addr_block_ts', 'starknet_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_starknet_sepolia_labels_label_addr_name', 'starknet_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_xai_labels_addr_block_ts', 'xai_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_xai_labels_label_addr_name', 'xai_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_xai_sepolia_labels_addr_block_ts', 'xai_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_xai_sepolia_labels_label_addr_name', 'xai_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_xdai_labels_addr_block_ts', 'xdai_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_xdai_labels_label_addr_name', 'xdai_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_zksync_era_labels_addr_block_ts', 'zksync_era_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_zksync_era_labels_label_addr_name', 'zksync_era_labels', ['label', 'address', 'label_name'], unique=False)
    op.create_index('ix_zksync_era_sepolia_labels_addr_block_ts', 'zksync_era_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_zksync_era_sepolia_labels_label_addr_name', 'zksync_era_sepolia_labels', ['label', 'address', 'label_name'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('ix_zksync_era_sepolia_labels_label_addr_name', table_name='zksync_era_sepolia_labels')
    op.drop_index('ix_zksync_era_sepolia_labels_addr_block_ts', table_name='zksync_era_sepolia_labels')
    op.drop_index('ix_zksync_era_labels_label_addr_name', table_name='zksync_era_labels')
    op.drop_index('ix_zksync_era_labels_addr_block_ts', table_name='zksync_era_labels')
    op.drop_index('ix_xdai_labels_label_addr_name', table_name='xdai_labels')
    op.drop_index('ix_xdai_labels_addr_block_ts', table_name='xdai_labels')
    op.drop_index('ix_xai_sepolia_labels_label_addr_name', table_name='xai_sepolia_labels')
    op.drop_index('ix_xai_sepolia_labels_addr_block_ts', table_name='xai_sepolia_labels')
    op.drop_index('ix_xai_labels_label_addr_name', table_name='xai_labels')
    op.drop_index('ix_xai_labels_addr_block_ts', table_name='xai_labels')
    op.drop_index('ix_starknet_sepolia_labels_label_addr_name', table_name='starknet_sepolia_labels')
    op.drop_index('ix_starknet_sepolia_labels_addr_block_ts', table_name='starknet_sepolia_labels')
    op.drop_index('ix_starknet_labels_label_addr_name', table_name='starknet_labels')
    op.drop_index('ix_starknet_labels_addr_block_ts', table_name='starknet_labels')
    op.drop_index('ix_sepolia_labels_label_addr_name', table_name='sepolia_labels')
    op.drop_index('ix_sepolia_labels_addr_block_ts', table_name='sepolia_labels')
    op.drop_index('ix_ronin_saigon_labels_label_addr_name', table_name='ronin_saigon_labels')
    op.drop_index('ix_ronin_labels_label_addr_name', table_name='ronin_labels')
    op.drop_index('ix_proofofplay_apex_labels_label_addr_name', table_name='proofofplay_apex_labels')
    op.drop_index('ix_polygon_labels_label_addr_name', table_name='polygon_labels')
    op.drop_index('ix_polygon_labels_addr_block_ts', table_name='polygon_labels')
    op.drop_index('ix_mumbai_labels_label_addr_name', table_name='mumbai_labels')
    op.drop_index('ix_mumbai_labels_addr_block_ts', table_name='mumbai_labels')
    op.drop_index('ix_mantle_sepolia_labels_label_addr_name', table_name='mantle_sepolia_labels')
    op.drop_index('ix_mantle_labels_label_addr_name', table_name='mantle_labels')
    op.drop_index('ix_imx_zkevm_sepolia_labels_label_addr_name', table_name='imx_zkevm_sepolia_labels')
    op.drop_index('ix_imx_zkevm_labels_label_addr_name', table_name='imx_zkevm_labels')
    op.drop_index('ix_game7_testnet_labels_label_addr_name', table_name='game7_testnet_labels')
    op.drop_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_tx_call_raw', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"))
    op.drop_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_tx_call', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer-raw' and label_type='event'"))
    op.drop_index('uk_game7_orbit_arbitrum_sepolia_labels_tx_hash_log_idx_evt', table_name='game7_orbit_arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('ix_game7_orbit_arbitrum_sepolia_labels_label_addr_name', table_name='game7_orbit_arbitrum_sepolia_labels')
    op.drop_index('ix_game7_orbit_arbitrum_sepolia_labels_addr_block_ts', table_name='game7_orbit_arbitrum_sepolia_labels')
    op.drop_index('ix_game7_orbit_arbitrum_sepolia_labels_addr_block_num', table_name='game7_orbit_arbitrum_sepolia_labels')
    op.create_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call_raw', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where="(((label)::text = 'seer-raw'::text) AND ((label_type)::text = 'tx_call'::text))")
    op.create_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where="(((label)::text = 'seer'::text) AND ((label_type)::text = 'tx_call'::text))")
    op.create_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where="(((label)::text = 'seer-raw'::text) AND ((label_type)::text = 'event'::text))")
    op.create_index('uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt', 'game7_orbit_arbitrum_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where="(((label)::text = 'seer'::text) AND ((label_type)::text = 'event'::text))")
    op.create_index('ix_g7o_arbitrum_sepolia_labels_addr_block_ts', 'game7_orbit_arbitrum_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index('ix_g7o_arbitrum_sepolia_labels_addr_block_num', 'game7_orbit_arbitrum_sepolia_labels', ['address', 'block_number'], unique=False)
    op.drop_index('ix_game7_labels_label_addr_name', table_name='game7_labels')
    op.drop_index('ix_ethereum_labels_label_addr_name', table_name='ethereum_labels')
    op.drop_index('ix_ethereum_labels_addr_block_ts', table_name='ethereum_labels')
    op.drop_index('ix_blast_sepolia_labels_label_addr_name', table_name='blast_sepolia_labels')
    op.drop_index('ix_blast_labels_label_addr_name', table_name='blast_labels')
    op.drop_index('ix_base_labels_label_addr_name', table_name='base_labels')
    op.drop_index('ix_base_labels_addr_block_ts', table_name='base_labels')
    op.drop_index('ix_b3_sepolia_labels_label_addr_name', table_name='b3_sepolia_labels')
    op.drop_index('ix_b3_labels_label_addr_name', table_name='b3_labels')
    op.drop_index('ix_avalanche_labels_label_addr_name', table_name='avalanche_labels')
    op.drop_index('ix_avalanche_labels_addr_block_ts', table_name='avalanche_labels')
    op.drop_index('ix_avalanche_fuji_labels_label_addr_name', table_name='avalanche_fuji_labels')
    op.drop_index('ix_avalanche_fuji_labels_addr_block_ts', table_name='avalanche_fuji_labels')
    op.drop_index('ix_arbitrum_sepolia_labels_label_addr_name', table_name='arbitrum_sepolia_labels')
    op.drop_index('ix_arbitrum_sepolia_labels_addr_block_ts', table_name='arbitrum_sepolia_labels')
    op.drop_index('ix_arbitrum_one_labels_label_addr_name', table_name='arbitrum_one_labels')
    op.drop_index('ix_arbitrum_nova_labels_label_addr_name', table_name='arbitrum_nova_labels')
    op.drop_index('ix_amoy_labels_label_addr_name', table_name='amoy_labels')
    # ### end Alembic commands ###



"""add-b3

Revision ID: 25b339f55f8f
Revises: 48d2562504d1
Create Date: 2024-09-11 13:58:54.884367

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "25b339f55f8f"
down_revision: Union[str, None] = "48d2562504d1"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "b3_blocks",
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("parent_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("row_id", sa.BigInteger(), nullable=False),
        sa.Column("path", sa.Text(), nullable=False),
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column(
            "indexed_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("block_number", name=op.f("pk_b3_blocks")),
    )
    op.create_index(
        op.f("ix_b3_blocks_block_number"), "b3_blocks", ["block_number"], unique=False
    )
    op.create_index(
        op.f("ix_b3_blocks_block_timestamp"),
        "b3_blocks",
        ["block_timestamp"],
        unique=False,
    )
    op.create_table(
        "b3_reorgs",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_b3_reorgs")),
    )
    op.create_index(
        op.f("ix_b3_reorgs_block_hash"), "b3_reorgs", ["block_hash"], unique=False
    )
    op.create_index(
        op.f("ix_b3_reorgs_block_number"), "b3_reorgs", ["block_number"], unique=False
    )
    op.create_table(
        "b3_sepolia_blocks",
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("parent_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("row_id", sa.BigInteger(), nullable=False),
        sa.Column("path", sa.Text(), nullable=False),
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
        sa.Column(
            "indexed_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("block_number", name=op.f("pk_b3_sepolia_blocks")),
    )
    op.create_index(
        op.f("ix_b3_sepolia_blocks_block_number"),
        "b3_sepolia_blocks",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_b3_sepolia_blocks_block_timestamp"),
        "b3_sepolia_blocks",
        ["block_timestamp"],
        unique=False,
    )
    op.create_table(
        "b3_sepolia_reorgs",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_b3_sepolia_reorgs")),
    )
    op.create_index(
        op.f("ix_b3_sepolia_reorgs_block_hash"),
        "b3_sepolia_reorgs",
        ["block_hash"],
        unique=False,
    )
    op.create_index(
        op.f("ix_b3_sepolia_reorgs_block_number"),
        "b3_sepolia_reorgs",
        ["block_number"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###

    op.drop_index(
        op.f("ix_b3_sepolia_reorgs_block_number"), table_name="b3_sepolia_reorgs"
    )
    op.drop_index(
        op.f("ix_b3_sepolia_reorgs_block_hash"), table_name="b3_sepolia_reorgs"
    )
    op.drop_table("b3_sepolia_reorgs")
    op.drop_index(
        op.f("ix_b3_sepolia_blocks_block_timestamp"), table_name="b3_sepolia_blocks"
    )
    op.drop_index(
        op.f("ix_b3_sepolia_blocks_block_number"), table_name="b3_sepolia_blocks"
    )
    op.drop_table("b3_sepolia_blocks")
    op.drop_index(op.f("ix_b3_reorgs_block_number"), table_name="b3_reorgs")
    op.drop_index(op.f("ix_b3_reorgs_block_hash"), table_name="b3_reorgs")
    op.drop_table("b3_reorgs")
    op.drop_index(op.f("ix_b3_blocks_block_timestamp"), table_name="b3_blocks")
    op.drop_index(op.f("ix_b3_blocks_block_number"), table_name="b3_blocks")
    op.drop_table("b3_blocks")
    # ### end Alembic commands ###



"""Add indexed_at logs and transactions

Revision ID: 48d2562504d1
Revises: b89a8affe2c3
Create Date: 2024-08-20 17:08:34.493114

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "48d2562504d1"
down_revision: Union[str, None] = "b89a8affe2c3"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "arbitrum_one_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "arbitrum_one_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "arbitrum_sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "arbitrum_sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "ethereum_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "ethereum_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "game7_orbit_arbitrum_sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "game7_orbit_arbitrum_sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "game7_testnet_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "game7_testnet_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "imx_zkevm_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "imx_zkevm_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "imx_zkevm_sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "imx_zkevm_sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "mantle_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "mantle_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "mantle_sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "mantle_sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "polygon_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "polygon_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "xai_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "xai_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "xai_sepolia_blocks",
        sa.Column("transactions_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    op.add_column(
        "xai_sepolia_blocks",
        sa.Column("logs_indexed_at", sa.DateTime(timezone=True), nullable=True),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("xai_sepolia_blocks", "logs_indexed_at")
    op.drop_column("xai_sepolia_blocks", "transactions_indexed_at")
    op.drop_column("xai_blocks", "logs_indexed_at")
    op.drop_column("xai_blocks", "transactions_indexed_at")
    op.drop_column("sepolia_blocks", "logs_indexed_at")
    op.drop_column("sepolia_blocks", "transactions_indexed_at")
    op.drop_column("polygon_blocks", "logs_indexed_at")
    op.drop_column("polygon_blocks", "transactions_indexed_at")
    op.drop_column("mantle_sepolia_blocks", "logs_indexed_at")
    op.drop_column("mantle_sepolia_blocks", "transactions_indexed_at")
    op.drop_column("mantle_blocks", "logs_indexed_at")
    op.drop_column("mantle_blocks", "transactions_indexed_at")
    op.drop_column("imx_zkevm_sepolia_blocks", "logs_indexed_at")
    op.drop_column("imx_zkevm_sepolia_blocks", "transactions_indexed_at")
    op.drop_column("imx_zkevm_blocks", "logs_indexed_at")
    op.drop_column("imx_zkevm_blocks", "transactions_indexed_at")
    op.drop_column("game7_testnet_blocks", "logs_indexed_at")
    op.drop_column("game7_testnet_blocks", "transactions_indexed_at")
    op.drop_column("game7_orbit_arbitrum_sepolia_blocks", "logs_indexed_at")
    op.drop_column("game7_orbit_arbitrum_sepolia_blocks", "transactions_indexed_at")
    op.drop_column("ethereum_blocks", "logs_indexed_at")
    op.drop_column("ethereum_blocks", "transactions_indexed_at")
    op.drop_column("arbitrum_sepolia_blocks", "logs_indexed_at")
    op.drop_column("arbitrum_sepolia_blocks", "transactions_indexed_at")
    op.drop_column("arbitrum_one_blocks", "logs_indexed_at")
    op.drop_column("arbitrum_one_blocks", "transactions_indexed_at")
    # ### end Alembic commands ###



"""add ronin chain

Revision ID: e6d3c285e7cc
Revises: d816689b786a
Create Date: 2024-11-12 12:54:33.415972

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "e6d3c285e7cc"
down_revision: Union[str, None] = "d816689b786a"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "ronin_labels",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("label", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=128), nullable=False),
        sa.Column("log_index", sa.Integer(), nullable=True),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("caller_address", sa.LargeBinary(), nullable=True),
        sa.Column("origin_address", sa.LargeBinary(), nullable=True),
        sa.Column("address", sa.LargeBinary(), nullable=False),
        sa.Column("label_name", sa.Text(), nullable=True),
        sa.Column("label_type", sa.VARCHAR(length=64), nullable=True),
        sa.Column("label_data", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_ronin_labels")),
        sa.UniqueConstraint("id", name=op.f("uq_ronin_labels_id")),
    )
    op.create_index(
        "ix_ronin_labels_addr_block_num",
        "ronin_labels",
        ["address", "block_number"],
        unique=False,
    )
    op.create_index(
        "ix_ronin_labels_addr_block_ts",
        "ronin_labels",
        ["address", "block_timestamp"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_labels_address"), "ronin_labels", ["address"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_labels_block_number"),
        "ronin_labels",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_labels_caller_address"),
        "ronin_labels",
        ["caller_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_labels_label"), "ronin_labels", ["label"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_labels_label_name"), "ronin_labels", ["label_name"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_labels_label_type"), "ronin_labels", ["label_type"], unique=False
    )
    op.create_index(
        op.f("ix_ronin_labels_origin_address"),
        "ronin_labels",
        ["origin_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_labels_transaction_hash"),
        "ronin_labels",
        ["transaction_hash"],
        unique=False,
    )
    op.create_index(
        "uk_ronin_labels_tx_hash_log_idx_evt",
        "ronin_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.create_index(
        "uk_ronin_labels_tx_hash_log_idx_evt_raw",
        "ronin_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_ronin_labels_tx_hash_tx_call",
        "ronin_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_ronin_labels_tx_hash_tx_call_raw",
        "ronin_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_table(
        "ronin_saigon_labels",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("label", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=128), nullable=False),
        sa.Column("log_index", sa.Integer(), nullable=True),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("caller_address", sa.LargeBinary(), nullable=True),
        sa.Column("origin_address", sa.LargeBinary(), nullable=True),
        sa.Column("address", sa.LargeBinary(), nullable=False),
        sa.Column("label_name", sa.Text(), nullable=True),
        sa.Column("label_type", sa.VARCHAR(length=64), nullable=True),
        sa.Column("label_data", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_ronin_saigon_labels")),
        sa.UniqueConstraint("id", name=op.f("uq_ronin_saigon_labels_id")),
    )
    op.create_index(
        "ix_ronin_saigon_labels_addr_block_num",
        "ronin_saigon_labels",
        ["address", "block_number"],
        unique=False,
    )
    op.create_index(
        "ix_ronin_saigon_labels_addr_block_ts",
        "ronin_saigon_labels",
        ["address", "block_timestamp"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_address"),
        "ronin_saigon_labels",
        ["address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_block_number"),
        "ronin_saigon_labels",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_caller_address"),
        "ronin_saigon_labels",
        ["caller_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_label"),
        "ronin_saigon_labels",
        ["label"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_label_name"),
        "ronin_saigon_labels",
        ["label_name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_label_type"),
        "ronin_saigon_labels",
        ["label_type"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_origin_address"),
        "ronin_saigon_labels",
        ["origin_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_ronin_saigon_labels_transaction_hash"),
        "ronin_saigon_labels",
        ["transaction_hash"],
        unique=False,
    )
    op.create_index(
        "uk_ronin_saigon_labels_tx_hash_log_idx_evt",
        "ronin_saigon_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.create_index(
        "uk_ronin_saigon_labels_tx_hash_log_idx_evt_raw",
        "ronin_saigon_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_ronin_saigon_labels_tx_hash_tx_call",
        "ronin_saigon_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_ronin_saigon_labels_tx_hash_tx_call_raw",
        "ronin_saigon_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "uk_ronin_saigon_labels_tx_hash_tx_call_raw",
        table_name="ronin_saigon_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_ronin_saigon_labels_tx_hash_tx_call",
        table_name="ronin_saigon_labels",
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_ronin_saigon_labels_tx_hash_log_idx_evt_raw",
        table_name="ronin_saigon_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_ronin_saigon_labels_tx_hash_log_idx_evt",
        table_name="ronin_saigon_labels",
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_transaction_hash"),
        table_name="ronin_saigon_labels",
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_origin_address"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_label_type"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_label_name"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_label"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_caller_address"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_block_number"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        op.f("ix_ronin_saigon_labels_address"), table_name="ronin_saigon_labels"
    )
    op.drop_index(
        "ix_ronin_saigon_labels_addr_block_ts", table_name="ronin_saigon_labels"
    )
    op.drop_index(
        "ix_ronin_saigon_labels_addr_block_num", table_name="ronin_saigon_labels"
    )
    op.drop_table("ronin_saigon_labels")
    op.drop_index(
        "uk_ronin_labels_tx_hash_tx_call_raw",
        table_name="ronin_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_ronin_labels_tx_hash_tx_call",
        table_name="ronin_labels",
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_ronin_labels_tx_hash_log_idx_evt_raw",
        table_name="ronin_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_ronin_labels_tx_hash_log_idx_evt",
        table_name="ronin_labels",
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.drop_index(op.f("ix_ronin_labels_transaction_hash"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_origin_address"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_label_type"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_label_name"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_label"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_caller_address"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_block_number"), table_name="ronin_labels")
    op.drop_index(op.f("ix_ronin_labels_address"), table_name="ronin_labels")
    op.drop_index("ix_ronin_labels_addr_block_ts", table_name="ronin_labels")
    op.drop_index("ix_ronin_labels_addr_block_num", table_name="ronin_labels")
    op.drop_table("ronin_labels")
    # ### end Alembic commands ###



"""Add deploy block

Revision ID: 6807bdf6f417
Revises: 48d2562504d1
Create Date: 2024-08-23 16:51:47.147758

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "6807bdf6f417"
down_revision: Union[str, None] = "25b339f55f8f"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "abi_jobs",
        sa.Column("deployment_block_number", sa.BigInteger(), nullable=True),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("abi_jobs", "deployment_block_number")
    # ### end Alembic commands ###



"""
Moonstream database V3

Example of label_data column record:
    {
        "label": "ERC20",
        "label_data": {
            "name": "Uniswap",
            "symbol": "UNI"
        }
    },
    {
        "label": "Exchange"
        "label_data": {...}
    }
"""

import os
import uuid

from sqlalchemy import (
    VARCHAR,
    BigInteger,
    Column,
    DateTime,
    Index,
    Integer,
    LargeBinary,
    MetaData,
    Text,
)
from sqlalchemy.dialects.postgresql import JSONB, UUID
from sqlalchemy.ext.compiler import compiles
from sqlalchemy.ext.declarative import declarative_base, declared_attr
from sqlalchemy.sql import expression, text

"""
Naming conventions doc
https://docs.sqlalchemy.org/en/20/core/constraints.html#configuring-constraint-naming-conventions
"""
convention = {
    "ix": "ix_%(column_0_label)s",
    "uq": "uq_%(table_name)s_%(column_0_name)s",
    "ck": "ck_%(table_name)s_%(constraint_name)s",
    "fk": "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
    "pk": "pk_%(table_name)s",
}
metadata = MetaData(naming_convention=convention)
Base = declarative_base(metadata=metadata)

"""
Creating a utcnow function which runs on the Posgres database server when created_at and updated_at
fields are populated.
Following:
1. https://docs.sqlalchemy.org/en/13/core/compiler.html#utc-timestamp-function
2. https://www.postgresql.org/docs/current/functions-datetime.html#FUNCTIONS-DATETIME-CURRENT
3. https://stackoverflow.com/a/33532154/13659585
"""

MOONSTREAM_DB_V3_SCHEMA_NAME = os.environ.get(
    "MOONSTREAM_DB_V3_SCHEMA_NAME", "blockchain"
)


class utcnow(expression.FunctionElement):
    type = DateTime  # type: ignore


@compiles(utcnow, "postgresql")
def pg_utcnow(element, compiler, **kwargs):
    return "TIMEZONE('utc', statement_timestamp())"


class EvmBasedLabel(Base):  # type: ignore
    __abstract__ = True

    @declared_attr
    def __table_args__(cls):
        return (
            Index(
                f"ix_{cls.__tablename__}_addr_block_num",
                "address", "block_number", unique=False
            ),
            Index(
                f"ix_{cls.__tablename__}_addr_block_ts",
                "address", "block_timestamp", unique=False
            ),
            Index(
                f"ix_{cls.__tablename__}_label_addr_name",
                "label", "address", "label_name", unique=False
            ),
            Index(
                f"uk_{cls.__tablename__}_tx_hash_tx_call",
                "transaction_hash", unique=True,
                postgresql_where=text("label='seer' and label_type='tx_call'")
            ),
            Index(
                f"uk_{cls.__tablename__}_tx_hash_log_idx_evt",
                "transaction_hash", "log_index", unique=True,
                postgresql_where=text("label='seer' and label_type='event'")
            ),
            Index(
                f"uk_{cls.__tablename__}_tx_hash_tx_call_raw",
                "transaction_hash", unique=True,
                postgresql_where=text("label='seer-raw' and label_type='tx_call'")
            ),
            Index(
                f"uk_{cls.__tablename__}_tx_hash_log_idx_evt_raw",
                "transaction_hash", "log_index", unique=True,
                postgresql_where=text("label='seer-raw' and label_type='event'")
            )
        )
    id = Column(
        UUID(as_uuid=True),
        primary_key=True,
        default=uuid.uuid4,
        unique=True,
        nullable=False,
    )
    label = Column(VARCHAR(256), nullable=False, index=True)

    transaction_hash = Column(
        VARCHAR(128),
        nullable=True,
        index=True,
    )
    log_index = Column(Integer, nullable=True)

    block_number = Column(
        BigInteger,
        nullable=False,
        index=True,
    )
    block_hash = Column(VARCHAR(256), nullable=True)
    block_timestamp = Column(BigInteger, nullable=True)

    caller_address = Column(
        LargeBinary,
        nullable=True,
        index=True,
    )
    origin_address = Column(
        LargeBinary,
        nullable=True,
        index=True,
    )

    address = Column(
        LargeBinary,
        nullable=False,
        index=True,
    )

    label_name = Column(Text, nullable=True, index=True)
    label_type = Column(VARCHAR(64), nullable=True, index=True)
    label_data = Column(JSONB, nullable=True)

    created_at = Column(
        DateTime(timezone=True), server_default=utcnow(), nullable=False
    )


class EthereumLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "ethereum_labels"

class SepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "sepolia_labels"

class PolygonLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "polygon_labels"

class MumbaiLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "mumbai_labels"

class AmoyLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "amoy_labels"

class XDaiLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "xdai_labels"

class ZkSyncEraLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "zksync_era_labels"

class ZkSyncEraSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "zksync_era_sepolia_labels"

class BaseLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "base_labels"

class ArbitrumNovaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "arbitrum_nova_labels"

class ArbitrumOneLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "arbitrum_one_labels"

class ArbitrumSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "arbitrum_sepolia_labels"

class Game7OrbitArbitrumSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "game7_orbit_arbitrum_sepolia_labels"

class XaiLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "xai_labels"

class XaiSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "xai_sepolia_labels"

class AvalancheLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "avalanche_labels"

class AvalancheFujiLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "avalanche_fuji_labels"

class BlastLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "blast_labels"

class BlastSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "blast_sepolia_labels"

class ProofOfPlayApexLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "proofofplay_apex_labels"

class StarknetLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "starknet_labels"

class StarknetSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "starknet_sepolia_labels"

class MantleLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "mantle_labels"

class MantleSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "mantle_sepolia_labels"

class ImxZkevmLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "imx_zkevm_labels"

class ImxZkevmSepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "imx_zkevm_sepolia_labels"

class Game7Label(EvmBasedLabel):  # type: ignore
    __tablename__ = "game7_labels"

class Game7TestnetLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "game7_testnet_labels"

class B3Label(EvmBasedLabel):  # type: ignore
    __tablename__ = "b3_labels"

class B3SepoliaLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "b3_sepolia_labels"

class RoninLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "ronin_labels"

class RoninSaigonLabel(EvmBasedLabel):  # type: ignore
    __tablename__ = "ronin_saigon_labels"

